@@ -1,5 +1,8 @@
+import functools
+
+
 class IntervalSet(object):
-    """A class to hold collections of intervals, otherwise known as discontinous ranges"""
+    """A class to hold collections of intervals, otherwise known as discontinuous ranges"""
 
     _data = set()
 
@@ -94,3 +97,7 @@ class IntervalSet(object):
                 self._add(el)
         elif len(to_add) == 1:
             self._add(to_add.pop())
+
+    def complement(self):
+        intersection = lambda a, b: a.intersection(b)
+        return functools.reduce(intersection, [interval.complement() for interval in list(self)])
